@@ -65,9 +65,12 @@ class ChannelHandler(QObject):
 
 class TerminalWidget(QFrame, SpyderWidgetMixin):
     """Terminal widget."""
+    zdotdir = os.environ.get('ZDOTDIR') or os.environ.get('HOME')  # what about windows?
     ENV_ROUTES = {
-        "bash": ["~/.bashrc", "~/.bash_profile"],
-        "zsh": ["~/.zshrc"],
+        "bash": ["/etc/profile", "~/.bash_profile"],
+        "zsh": ["/etc/zshenv", f"{zdotdir}/.zshenv", "/etc/zprofile",
+                f"{zdotdir}/.zprofile", "/etc/zshrc", f"{zdotdir}/.zshrc",
+                "/etc/zlogin", f"{zdotdir}/.zlogin"],
         "fish": ["~/.config/fish/config.fish"],
         "sh": ["~/.profile", "~/.shrc", "~/.shinit"],
         "ksh": ["~/.profile", "~/.kshrc"],
@@ -234,10 +237,10 @@ class TerminalWidget(QFrame, SpyderWidgetMixin):
         zoom = self.get_conf('zoom')
         if zoom > 0:
             for __ in range(0, zoom):
-                self.view.increase_font()
+                self.view.increase_font(new_term=True)
         if zoom < 0:
             for __ in range(0, -zoom):
-                self.view.decrease_font()
+                self.view.decrease_font(new_term=True)
 
     def set_option(self, option_name, option):
         """Set a configuration option in the terminal."""
@@ -358,16 +361,18 @@ class TermView(QWebEngineView, SpyderWidgetMixin):
         """Clear the terminal."""
         self.eval_javascript('clearTerm()')
 
-    def increase_font(self):
+    def increase_font(self, new_term=False):
         """Increase terminal font."""
-        zoom = self.get_conf('zoom')
-        self.set_conf('zoom', zoom + 1)
+        if not new_term:
+            zoom = self.get_conf('zoom')
+            self.set_conf('zoom', zoom + 1)
         return self.eval_javascript('increaseFontSize()')
 
-    def decrease_font(self):
+    def decrease_font(self, new_term=False):
         """Decrease terminal font."""
-        zoom = self.get_conf('zoom')
-        self.set_conf('zoom', zoom - 1)
+        if not new_term:
+            zoom = self.get_conf('zoom')
+            self.set_conf('zoom', zoom - 1)
         return self.eval_javascript('decreaseFontSize()')
 
     def contextMenuEvent(self, event):
